'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.INVALID_REQUEST = exports.NO_RESULTS_FOUND = exports.endpoint = undefined;

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

exports.parseLatLngJSON = parseLatLngJSON;
exports.default = getStateZipFromLatLng;

var _requestPromiseNative = require('request-promise-native');

var _requestPromiseNative2 = _interopRequireDefault(_requestPromiseNative);

var _isValidGeoCoordinates = require('../../../geolib/isValidGeoCoordinates');

var _isValidGeoCoordinates2 = _interopRequireDefault(_isValidGeoCoordinates);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var endpoint = exports.endpoint = function endpoint(lat, lng) {
    return 'https://maps.googleapis.com/maps/api/geocode/json?latlng=' + lat + ',' + lng;
};

var NO_RESULTS_FOUND = exports.NO_RESULTS_FOUND = function NO_RESULTS_FOUND(lat, lng) {
    return 'No results found for latitude: "' + lat + '", longitude: "' + lng + '"';
};

var INVALID_REQUEST = exports.INVALID_REQUEST = function INVALID_REQUEST(lat, lng) {
    return 'Invalid parameters for latitude: "' + lat + '", longitude: "' + lng + '".';
};

function parseLatLngJSON(_ref) {
    var results = _ref.results;

    var _results = _slicedToArray(results, 1),
        first = _results[0];

    var components = first && first.address_components;

    var state = void 0;
    var zip = void 0;
    var country = void 0;

    components.find(function (_ref2) {
        var short_name = _ref2.short_name,
            types = _ref2.types;

        if (types && types.indexOf('country') !== -1) {
            // eslint-disable-next-line camelcase
            country = short_name;
            return true;
        }
        return false;
    });

    if (country && country === 'US') {
        components.find(function (_ref3) {
            var types = _ref3.types,
                short_name = _ref3.short_name;

            if (types.indexOf('administrative_area_level_1') !== -1) {
                // eslint-disable-next-line camelcase
                state = short_name;
                return true;
            }
            return false;
        });

        components.find(function (_ref4) {
            var types = _ref4.types,
                short_name = _ref4.short_name;

            if (types.indexOf('postal_code') !== -1) {
                // eslint-disable-next-line camelcase
                zip = short_name;
                return true;
            }
            return false;
        });
    }

    return {
        zip: zip,
        state: state,
        country: country
    };
}

function getStateZipFromLatLng(lat, lng) {

    if (!(0, _isValidGeoCoordinates2.default)([lng, lat])) {
        return Promise.reject({
            statusCode: 400,
            // eslint-disable-next-line babel/new-cap
            message: INVALID_REQUEST(lat, lng)
        });
    }

    return _requestPromiseNative2.default.get({
        json: true,
        uri: endpoint(lat, lng)
    }).then(function (data) {
        var status = data.status;


        switch (status) {

            case 'OK':
                return data;

            case 'ZERO_RESULTS':
                return Promise.reject({
                    statusCode: 404,
                    // eslint-disable-next-line babel/new-cap
                    message: NO_RESULTS_FOUND(lat, lng)
                });

            default:
                return Promise.reject({
                    statusCode: 400,
                    // eslint-disable-next-line babel/new-cap
                    message: INVALID_REQUEST(lat, lng)
                });
        }
    }).then(parseLatLngJSON);
}